@@ -168,6 +168,14 @@ seed_release_arg (GITransfer transfer,
 	  {
 	    interface_info = g_type_info_get_interface (type_info);
 
+	    GIInfoType interface_type = g_base_info_get_type (interface_info);
+	    if (interface_type == GI_INFO_TYPE_CALLBACK)
+	      {
+	        /* FIXME: - callback returns are not handled yet */
+	        g_base_info_unref (interface_info);
+	        break;
+	      }
+
 	    gtype =
 	      g_registered_type_info_get_g_type ((GIRegisteredTypeInfo *)
 						 interface_info);
@@ -381,7 +389,7 @@ seed_gi_make_array (JSContextRef ctx,
 	*array_p = dblresult;
       }
       break;
-    case GI_TYPE_TAG_INT:
+    case GI_TYPE_TAG_INT32:
       {
 	gint *intresult;
 
@@ -481,10 +489,28 @@ seed_gi_make_argument (JSContextRef ctx,
   switch (gi_tag)
     {
     case GI_TYPE_TAG_VOID:
-      // things like gio.outputstream.write use void pointers
+      
       if (g_type_info_is_pointer (type_info))
-          arg->v_string = seed_value_to_string (ctx, value, exception);
+      {
+        GObject *gobject;
+        if (JSValueIsString (ctx, value)) 
+          {
+          /* 
+            things like gio.outputstream.write use void pointers 
+            might need a few other types here.. 
+            not very well memory managed. - should be solved by bytearrays when
+            introspection implements it.  
+          */
+          arg->v_string = seed_value_to_string (ctx, value, exception); 
+          break;
+        }
+        /* gtk_statusicon_position_menu / gtk_menu_popup use the userdata for the Gobject */
+        gobject = seed_value_to_object (ctx, value, exception);
+        if (!gobject)
+          return FALSE;
 
+        arg->v_pointer = gobject;
+      }
       break;
     case GI_TYPE_TAG_BOOLEAN:
       arg->v_boolean = seed_value_to_boolean (ctx, value, exception);
@@ -507,30 +533,12 @@ seed_gi_make_argument (JSContextRef ctx,
     case GI_TYPE_TAG_UINT32:
       arg->v_uint32 = seed_value_to_uint (ctx, value, exception);
       break;
-    case GI_TYPE_TAG_LONG:
-      arg->v_long = seed_value_to_long (ctx, value, exception);
-      break;
     case GI_TYPE_TAG_INT64:
       arg->v_int64 = seed_value_to_int64 (ctx, value, exception);
       break;
-    case GI_TYPE_TAG_ULONG:
-      arg->v_ulong = seed_value_to_ulong (ctx, value, exception);
-      break;
     case GI_TYPE_TAG_UINT64:
       arg->v_uint64 = seed_value_to_uint64 (ctx, value, exception);
       break;
-    case GI_TYPE_TAG_INT:
-      arg->v_int = seed_value_to_int (ctx, value, exception);
-      break;
-    case GI_TYPE_TAG_UINT:
-      arg->v_uint = seed_value_to_uint (ctx, value, exception);
-      break;
-    case GI_TYPE_TAG_SIZE:
-      arg->v_size = seed_value_to_size (ctx, value, exception);
-      break;
-    case GI_TYPE_TAG_SSIZE:
-      arg->v_ssize = seed_value_to_ssize (ctx, value, exception);
-      break;
     case GI_TYPE_TAG_FLOAT:
       arg->v_float = seed_value_to_float (ctx, value, exception);
       break;
@@ -546,9 +554,6 @@ seed_gi_make_argument (JSContextRef ctx,
     case GI_TYPE_TAG_GTYPE:
       arg->v_int = seed_value_to_int (ctx, value, exception);
       break;
-    case GI_TYPE_TAG_TIME_T:
-      arg->v_long = seed_value_to_time_t (ctx, value, exception);
-      break;
     case GI_TYPE_TAG_INTERFACE:
       {
 	GIBaseInfo *interface;
@@ -789,22 +794,10 @@ seed_gi_argument_make_js (JSContextRef ctx,
       return seed_value_from_int (ctx, arg->v_int32, exception);
     case GI_TYPE_TAG_UINT32:
       return seed_value_from_uint (ctx, arg->v_uint32, exception);
-    case GI_TYPE_TAG_LONG:
-      return seed_value_from_long (ctx, arg->v_long, exception);
     case GI_TYPE_TAG_INT64:
       return seed_value_from_int64 (ctx, arg->v_int64, exception);
-    case GI_TYPE_TAG_ULONG:
-      return seed_value_from_ulong (ctx, arg->v_ulong, exception);
     case GI_TYPE_TAG_UINT64:
       return seed_value_from_uint64 (ctx, arg->v_uint64, exception);
-    case GI_TYPE_TAG_INT:
-      return seed_value_from_int (ctx, arg->v_int32, exception);
-    case GI_TYPE_TAG_UINT:
-      return seed_value_from_uint (ctx, arg->v_uint32, exception);
-    case GI_TYPE_TAG_SSIZE:
-      return seed_value_from_ssize (ctx, arg->v_ssize, exception);
-    case GI_TYPE_TAG_SIZE:
-      return seed_value_from_size (ctx, arg->v_size, exception);
     case GI_TYPE_TAG_FLOAT:
       return seed_value_from_float (ctx, arg->v_float, exception);
     case GI_TYPE_TAG_DOUBLE:
@@ -815,8 +808,6 @@ seed_gi_argument_make_js (JSContextRef ctx,
       return seed_value_from_filename (ctx, arg->v_string, exception);
     case GI_TYPE_TAG_GTYPE:
       return seed_value_from_int (ctx, arg->v_int, exception);
-    case GI_TYPE_TAG_TIME_T:
-      return seed_value_from_time_t (ctx, arg->v_long, exception);
     case GI_TYPE_TAG_ARRAY:
       {
 	GITypeInfo *param_type;
@@ -870,7 +861,17 @@ seed_gi_argument_make_js (JSContextRef ctx,
 
 	    return strukt;
 	  }
+	else if (interface_type == GI_INFO_TYPE_CALLBACK)
+	  { 
+	    /* FIXME: return values of type callback are not handled yet. */
+	    g_base_info_unref (interface);
+	    return FALSE;
+	  }
+	/* fall through - other types?? */
+	g_base_info_unref (interface);
+	return FALSE;
       }
+
     case GI_TYPE_TAG_GLIST:
       {
 	GITypeInfo *list_type;
